==> gambit-0.2007.12.04.tar.gz: gambit-0.2007.12.04/src/tools/enumpoly/behavextend.h <==
//
// $Source$
// $Date: 2007-07-26 13:32:23 -0500 (Thu, 26 Jul 2007) $
// $Revision: 6263 $
//
// DESCRIPTION:
// Algorithms for extending behavior profiles to Nash equilibria
//
// This file is part of Gambit
// Copyright (c) 2002, The Gambit Project
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef BEHAVEXTEND_H
#define BEHAVEXTEND_H

#include "libgambit/libgambit.h"

class algExtendsToNash {
public:
  bool ExtendsToNash(const Gambit::MixedBehavProfile<double> &p_solution,
		     const Gambit::BehavSupport &p_littleSupport,
		     const Gambit::BehavSupport &p_bigSupport);
};

class algExtendsToAgentNash {
public:
  bool ExtendsToAgentNash(const Gambit::MixedBehavProfile<double> &p_solution,
			  const Gambit::BehavSupport &p_littleSupport,
			  const Gambit::BehavSupport &p_bigSupport);
};



#endif   // BEHAVEXTEND_H

==> gambit-15.1.1.tar.gz: gambit-15.1.1/src/tools/enumpoly/behavextend.h <==
//
// This file is part of Gambit
// Copyright (c) 1994-2014, The Gambit Project (http://www.gambit-project.org)
//
// FILE: src/tools/enumpoly/behavextend.h
// Algorithms for extending behavior profiles to Nash equilibria
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef BEHAVEXTEND_H
#define BEHAVEXTEND_H

#include "libgambit/libgambit.h"

class algExtendsToNash {
public:
  bool ExtendsToNash(const Gambit::MixedBehaviorProfile<double> &p_solution,
		     const Gambit::BehaviorSupportProfile &p_littleSupport,
		     const Gambit::BehaviorSupportProfile &p_bigSupport);
};

class algExtendsToAgentNash {
public:
  bool ExtendsToAgentNash(const Gambit::MixedBehaviorProfile<double> &p_solution,
			  const Gambit::BehaviorSupportProfile &p_littleSupport,
			  const Gambit::BehaviorSupportProfile &p_bigSupport);
};



#endif   // BEHAVEXTEND_H
